package org.s4s.gui.views;

import com.vaadin.data.util.BeanContainer;
import com.vaadin.data.util.BeanItem;
import com.vaadin.event.ItemClickEvent;
import com.vaadin.navigator.ViewChangeListener;
import com.vaadin.server.FontAwesome;
import com.vaadin.server.VaadinSession;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Label;
import com.vaadin.ui.Notification;
import com.vaadin.ui.Table;
import com.vaadin.ui.TextField;
import com.vaadin.ui.UI;
import java.util.HashSet;
import java.util.Set;
import org.s4s.dao.ProductDAO;
import org.s4s.dao.ShopSearchDAO;
import org.s4s.exceptions.DAOException;
import org.s4s.modell.dto.Product;
import org.s4s.modell.dto.Shop;
import org.s4s.modell.dto.Warenkorb;
import org.s4s.process.control.ProductSearch;
import org.s4s.process.control.ShopSearch;
import org.s4s.services.util.Roles;

/**
 *
 * @author Holger
 */
public class ShopView extends TemplateView {

    private final ProductDAO products = ProductSearch.getInstance();
    private final ShopSearchDAO shops = ShopSearch.getInstance();
    private Product product = null;
    private final Warenkorb warenkorb = Warenkorb.getInstance();

    @Override
    public void enter(ViewChangeListener.ViewChangeEvent event) {
        this.setUp();
        if (event.getParameters() != null) {
            // split at "/", add each part as a label
            String str = event.getParameters();
            search(str);
        }
    }

    public void setUp() {
        //super.setUpFooterAndHeader(this);
        //   setSizeFull();
        setMargin(true);

        final HorizontalLayout searchLayout = new HorizontalLayout();
        final HorizontalLayout buttonLayout = new HorizontalLayout();

        TextField textfield = new TextField();
        Button button = new Button("Suche", FontAwesome.SEARCH);
        Label label = new Label("Das erste Label unseres Shop in Shop System");

        buttonLayout.addComponent(label);
        buttonLayout.setComponentAlignment(label, Alignment.TOP_LEFT);

        searchLayout.addComponent(textfield);
        searchLayout.addComponent(button);
        buttonLayout.addComponent(searchLayout);
        buttonLayout.setComponentAlignment(searchLayout, Alignment.TOP_RIGHT);
        buttonLayout.setSizeFull();
        addComponent(buttonLayout);
        //setComponentAlignment(buttonLayout, Alignment.TOP_CENTER);

        final BeanContainer<Integer, Product> data = new BeanContainer<>(Product.class);
        data.setBeanIdProperty("id");
        final Table table = new Table("Products", data);
        table.setSizeFull();
        table.setSelectable(true);
        Set<Product> liste = new HashSet<>();

        final BeanContainer<Integer, Shop> dataShops = new BeanContainer<>(Shop.class);
        dataShops.setBeanIdProperty("id");
        final Table tableShops = new Table("Shops", dataShops);
        tableShops.setSizeFull();
        Set<Shop> listeShops = new HashSet<>();

        VaadinSession session = UI.getCurrent().getSession();
        if (session.getAttribute(Roles.CURRENTUSER) != null) {
            System.out.println(session.getAttribute(Roles.CURRENTUSER));
            Button addButton = new Button("Hinzufügen");

            addButton.addClickListener((event) -> {
                if (this.product == null) {
                    Notification.show(null, "Bitte Produkt(e) auswählen!", Notification.Type.HUMANIZED_MESSAGE);
                } else {
                    warenkorb.add(product);
                    System.out.println(warenkorb.getAnzahl());
                }
            });

            addComponent(addButton);
            setComponentAlignment(addButton, Alignment.MIDDLE_CENTER);
        }
        table.addItemClickListener(new ItemClickEvent.ItemClickListener() {
            @Override
            public void itemClick(ItemClickEvent event) {
                BeanItem<Product> productBean = data.getItem(event.getItemId());
                product = productBean.getBean();
            }
        });

        button.addClickListener(new Button.ClickListener() {
            @Override
            public void buttonClick(Button.ClickEvent event) {
                String str = textfield.getValue().trim();
                search(str);
                /*
                if (str.equals("")) {
                Notification.show(null, "Bitte gesuchtes Produkt eingeben!", Notification.Type.WARNING_MESSAGE);
                } else {
                addComponent(table);
                addComponent(tableShops);
                try {
                liste.addAll(products.getProductByName(str));
                liste.addAll(products.getProductByDescription(str));
                listeShops.addAll(shops.getShopByName(str));
                listeShops.addAll(shops.getShopByOwner(str));
                } catch (Exception ex) {
                //eig. DAO Exception, aber fehler...
                }
                data.removeAllItems();
                dataShops.removeAllItems();
                data.addAll(liste);
                dataShops.addAll(listeShops);
                table.setPageLength(table.size());
                tableShops.setPageLength(tableShops.size());
                }
                });
                 */
                // BeanItem<Product> item = (BeanItem) liste.getItem(liste.getValue);
                //  Product myBean = item.getBean();
            }
        });
    }

    private void search(String str) {
        final BeanContainer<Integer, Product> data = new BeanContainer<>(Product.class);
        data.setBeanIdProperty("id");
        final Table table = new Table("Products", data);
        table.setSizeFull();
        table.setSelectable(true);
        Set<Product> liste = new HashSet<>();
        if ("".equals(str)) {
            Notification.show(null, "Bitte gesuchtes Produkt eingeben!", Notification.Type.WARNING_MESSAGE);
        } else {
            addComponent(table);
            try {
                liste.addAll(products.getProductByName(str));
                liste.addAll(products.getProductByDescription(str));
            } catch (DAOException ex) {

            }
            data.removeAllItems();
            data.addAll(liste);
            table.setPageLength(table.size());

            table.addItemClickListener((ItemClickEvent event) -> {
                BeanItem<Product> productBean = data.getItem(event.getItemId());
                product = productBean.getBean();
            });
        }
    }
}
